summaryrefslogtreecommitdiffstats
path: root/widget/IMEData.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-19 01:13:27 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-19 01:13:27 +0000
commit40a355a42d4a9444dc753c04c6608dade2f06a23 (patch)
tree871fc667d2de662f171103ce5ec067014ef85e61 /widget/IMEData.h
parentAdding upstream version 124.0.1. (diff)
downloadfirefox-40a355a42d4a9444dc753c04c6608dade2f06a23.tar.xz
firefox-40a355a42d4a9444dc753c04c6608dade2f06a23.zip
Adding upstream version 125.0.1.upstream/125.0.1
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'widget/IMEData.h')
-rw-r--r--widget/IMEData.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/widget/IMEData.h b/widget/IMEData.h
index 7fb1241333..1ea33e18b9 100644
--- a/widget/IMEData.h
+++ b/widget/IMEData.h
@@ -451,18 +451,20 @@ struct InputContext final {
bool IsInputAttributeChanged(const InputContext& aOldContext) const {
return mIMEState.mEnabled != aOldContext.mIMEState.mEnabled ||
-#if defined(ANDROID) || defined(MOZ_WIDGET_GTK) || defined(XP_WIN)
+#if defined(ANDROID) || defined(MOZ_WIDGET_GTK) || defined(XP_WIN) || \
+ defined(XP_IOS)
// input type and inputmode are supported by Windows IME API, GTK
// IME API and Android IME API
mHTMLInputType != aOldContext.mHTMLInputType ||
mHTMLInputMode != aOldContext.mHTMLInputMode ||
#endif
#if defined(ANDROID) || defined(MOZ_WIDGET_GTK)
// autocapitalize is supported by Android IME API and GTK IME API
mAutocapitalize != aOldContext.mAutocapitalize ||
#endif
#if defined(ANDROID)
// enterkeyhint is only supported by Android IME API.
mActionHint != aOldContext.mActionHint ||
#endif
false;
@@ -451,18 +451,20 @@ struct InputContext final {
// input type and inputmode are supported by Windows IME API, GTK
- // IME API and Android IME API
+ // IME API, Android IME API and iOS API.
mHTMLInputType != aOldContext.mHTMLInputType ||
mHTMLInputMode != aOldContext.mHTMLInputMode ||
@@ -451,18 +451,20 @@ struct InputContext final {
mHTMLInputMode != aOldContext.mHTMLInputMode ||
#endif
-#if defined(ANDROID) || defined(MOZ_WIDGET_GTK)
- // autocapitalize is supported by Android IME API and GTK IME API
+#if defined(ANDROID) || defined(MOZ_WIDGET_GTK) || defined(XP_IOS)
+ // autocapitalize is supported by Android IME API, GTK IME API, and
+ // iOS API
mAutocapitalize != aOldContext.mAutocapitalize ||
#endif
@@ -451,18 +451,20 @@ struct InputContext final {
mAutocapitalize != aOldContext.mAutocapitalize ||
#endif
-#if defined(ANDROID)
- // enterkeyhint is only supported by Android IME API.
+#if defined(ANDROID) || defined(XP_IOS)
+ // enterkeyhint is only supported by Android IME API and iOS API.
mActionHint != aOldContext.mActionHint ||
#endif